initTimeout property
How long (in seconds) the Statsig client waits for the initial network request. Defaults to 3 seconds
Implementation
int initTimeout;
How long (in seconds) the Statsig client waits for the initial network request. Defaults to 3 seconds
int initTimeout;